@@ -1,52 +1,30 @@
-### R code from vignette source 'textplot-examples.Rnw'
-
-###################################################
-### code chunk number 1: preliminaries
-###################################################
+## ----preliminaries, echo=FALSE, results="hide"--------------------------------
 options(prompt = "R> ", continue = "+   ")
 options(prompt = " ", continue = "   ")
 set.seed(123456789)
+knitr::opts_chunk$set(message = FALSE, warning = FALSE, fig.align = "center")
 
-
-###################################################
-### code chunk number 2: textplot-examples.Rnw:47-55
-###################################################
-library(udpipe)
+## ----eval=(require(udpipe, quietly = TRUE) && require(ggraph, quietly = TRUE) && require(ggplot2, quietly = TRUE) && require(igraph, quietly = TRUE)), fig.width=10, fig.height=5----
 library(textplot)
+library(udpipe)
 library(ggraph)
+library(ggplot2)
 library(igraph)
 x <- udpipe("His speech about marshmallows in New York is utter bullshit",
             "english")
 plt <- textplot_dependencyparser(x, size = 4)
 plt
 
-
-###################################################
-### code chunk number 3: textplot-examples.Rnw:58-59
-###################################################
-print(plt)
-
-
-###################################################
-### code chunk number 4: textplot-examples.Rnw:64-68
-###################################################
+## ----eval=(require(udpipe, quietly = TRUE) && require(ggraph, quietly = TRUE) && require(ggplot2, quietly = TRUE) && require(igraph, quietly = TRUE)), fig.width=12, fig.height=6, out.width = '1\\textwidth', out.height = '0.5\\textwidth'----
 x <- udpipe("UDPipe provides tokenization, tagging, lemmatization and
              dependency parsing of raw text", "english")
 plt <- textplot_dependencyparser(x, size = 4)
 plt
 
-
-###################################################
-### code chunk number 5: textplot-examples.Rnw:71-72
-###################################################
-print(plt)
-
-
-###################################################
-### code chunk number 6: textplot-examples.Rnw:79-87
-###################################################
+## ----eval=(require(BTM, quietly = TRUE) && require(ggraph, quietly = TRUE) && require(ggforce, quietly = TRUE) && require(concaveman, quietly = TRUE) && require(igraph, quietly = TRUE)), fig.width=8, fig.height=6, out.width = '\\textwidth'----
 library(BTM)
 library(ggraph)
+library(ggforce)
 library(concaveman)
 library(igraph)
 data(example_btm, package = 'textplot')
@@ -54,34 +32,14 @@ model <- example_btm
 plt <- plot(model, title = "BTM model", top_n = 5)
 plt
 
-
-###################################################
-### code chunk number 7: textplot-examples.Rnw:90-91
-###################################################
-print(plt)
-
-
-###################################################
-### code chunk number 8: textplot-examples.Rnw:94-97
-###################################################
+## ----eval=(require(BTM, quietly = TRUE) && require(ggraph, quietly = TRUE) && require(ggforce, quietly = TRUE) && require(concaveman, quietly = TRUE) && require(igraph, quietly = TRUE)), fig.width=8, fig.height=6----
 plt <- plot(model, title = "Biterm topic model", subtitle = "Topics 2 to 8",
             which = 2:8, top_n = 7)
 plt
 
-
-###################################################
-### code chunk number 9: textplot-examples.Rnw:100-101
-###################################################
-print(plt)
-
-
-###################################################
-### code chunk number 10: textplot-examples.Rnw:105-128
-###################################################
-library(BTM)
+## ----eval=(require(data.table, quietly = TRUE) && require(udpipe, quietly = TRUE)), results="hide", fig.width=8, fig.height=6----
 library(data.table)
 library(udpipe)
-library(igraph)
 ## Annotate text with parts of speech tags
 data("brussels_reviews", package = "udpipe")
 anno <- subset(brussels_reviews, language %in% "nl")
@@ -93,6 +51,13 @@ biterms <- biterms[, cooccurrence(x = lemma,
                                   relevant = upos %in% c("NOUN", "PROPN", "ADJ"),
                                   skipgram = 2),
                      by = list(doc_id)]
+
+## ----eval=(require(BTM, quietly = TRUE) && require(ggraph, quietly = TRUE) && require(ggforce, quietly = TRUE) && require(concaveman, quietly = TRUE) && require(igraph, quietly = TRUE) && require(data.table, quietly = TRUE) && require(udpipe, quietly = TRUE)), results="hide", fig.width=8, fig.height=6----
+library(BTM)
+library(ggraph)
+library(ggforce)
+library(concaveman)
+library(igraph)
 ## Build the BTM model
 set.seed(123456)
 x <- subset(anno, upos %in% c("NOUN", "PROPN", "ADJ"))
@@ -102,19 +67,14 @@ model <- BTM(x, k = 5, beta = 0.01, iter = 2000, background = TRUE,
 plt <- plot(model)
 plt
 
-
-###################################################
-### code chunk number 11: textplot-examples.Rnw:131-132
-###################################################
-print(plt)
-
-
-###################################################
-### code chunk number 12: textplot-examples.Rnw:139-166
-###################################################
-library(udpipe)
-library(data.table)
+## ----eval=(require(BTM, quietly = TRUE) && require(ggraph, quietly = TRUE) && require(ggforce, quietly = TRUE) && require(concaveman, quietly = TRUE) && require(igraph, quietly = TRUE) && require(data.table, quietly = TRUE) && require(udpipe, quietly = TRUE)), fig.width=8, fig.height=8----
+library(BTM)
 library(ggraph)
+library(ggforce)
+library(concaveman)
+library(igraph)
+library(data.table)
+library(udpipe)
 x <- merge(anno, anno,
             by.x = c("doc_id", "paragraph_id", "sentence_id", "head_token_id"),
             by.y = c("doc_id", "paragraph_id", "sentence_id", "token_id"),
@@ -136,20 +96,11 @@ terminology <- data.frame(topic = terminology$topic,
                           probability = 1, stringsAsFactors = FALSE)
 plt <- textplot_bitermclusters(terminology, biterms,
                                labels = topiclabels,
-                               title = "Objects of verbs and adjectives modifying nouns",
+                               title = "Objects of verbs and adjectives-nouns",
                                subtitle = "Top 50 by group")
 plt
 
-
-###################################################
-### code chunk number 13: textplot-examples.Rnw:169-170
-###################################################
-print(plt)
-
-
-###################################################
-### code chunk number 14: textplot-examples.Rnw:178-187
-###################################################
+## ----fig.width=5.5, fig.height=5.5--------------------------------------------
 library(udpipe)
 data("brussels_reviews_anno", package = "udpipe")
 x   <- subset(brussels_reviews_anno, xpos %in% "JJ")
@@ -160,16 +111,7 @@ plt <- textplot_bar(x, top = 20,
                     addpct = TRUE, cexpct = 0.5)
 plt
 
-
-###################################################
-### code chunk number 15: textplot-examples.Rnw:190-191
-###################################################
-print(plt)
-
-
-###################################################
-### code chunk number 16: textplot-examples.Rnw:199-207
-###################################################
+## ----eval=(require(Rgraphviz, quietly = TRUE) && require(udpipe, quietly = TRUE) && require(data.table, quietly = TRUE) && require(graph, quietly = TRUE)), fig.width=5, fig.height=5----
 library(graph)
 library(Rgraphviz)
 library(udpipe)
@@ -179,10 +121,7 @@ dtm <- document_term_matrix(dtm)
 dtm <- dtm_remove_lowfreq(dtm, minfreq = 5)
 textplot_correlation_lines(dtm, top_n = 25, threshold = 0.01, lwd = 5, label = TRUE)
 
-
-###################################################
-### code chunk number 17: textplot-examples.Rnw:213-223
-###################################################
+## ----eval=(require(udpipe, quietly = TRUE) && require(data.table, quietly = TRUE) && require(qgraph, quietly = TRUE) && require(glasso, quietly = TRUE)), fig.width=6, fig.height=6----
 library(glasso)
 library(qgraph)
 library(udpipe)
@@ -194,13 +133,11 @@ dtm <- dtm_remove_tfidf(dtm, top = 100)
 term_correlations <- dtm_cor(dtm)
 textplot_correlation_glasso(term_correlations, exclude_zero = TRUE)
 
-
-###################################################
-### code chunk number 18: textplot-examples.Rnw:230-240
-###################################################
+## ----eval=(require(udpipe, quietly = TRUE) && require(igraph, quietly = TRUE) && require(ggraph, quietly = TRUE) && require(ggplot2, quietly = TRUE)), fig.width=6, fig.height=6, out.width = '0.75\\textwidth', out.height = '0.75\\textwidth'----
 library(udpipe)
-library(ggraph)
 library(igraph)
+library(ggraph)
+library(ggplot2)
 data(brussels_reviews_anno, package = 'udpipe')
 x <- subset(brussels_reviews_anno, xpos %in% "JJ" & language %in% "fr")
 x <- cooccurrence(x, group = "doc_id", term = "lemma")
@@ -209,29 +146,12 @@ plt <- textplot_cooccurrence(x,
                              title = "Adjective co-occurrences", top_n = 25)
 plt
 
-
-###################################################
-### code chunk number 19: textplot-examples.Rnw:243-244
-###################################################
-print(plt)
-
-
-###################################################
-### code chunk number 20: textplot-examples.Rnw:248-256 (eval = FALSE)
-###################################################
-## library(udpipe)
-## library(ggraph)
-## library(igraph)
-## library(data.table)
-## data("brussels_reviews", package = "udpipe")
-## anno <- subset(brussels_reviews, language %in% "nl")
-## anno <- data.frame(doc_id = anno$id, text = anno$feedback, stringsAsFactors = FALSE)
-## anno <- udpipe(anno, "dutch", trace = 10)
-
-
-###################################################
-### code chunk number 21: textplot-examples.Rnw:259-272
-###################################################
+## ----eval=(require(udpipe, quietly = TRUE) && require(igraph, quietly = TRUE) && require(ggraph, quietly = TRUE) && require(ggplot2, quietly = TRUE) && require(data.table, quietly = TRUE)), fig.width=8, fig.height=6, out.width = '0.8\\textwidth', out.height = '0.6\\textwidth'----
+library(udpipe)
+library(igraph)
+library(ggraph)
+library(ggplot2)
+library(data.table)
 biterms <- merge(anno, anno,
             by.x = c("doc_id", "paragraph_id", "sentence_id", "head_token_id"),
             by.y = c("doc_id", "paragraph_id", "sentence_id", "token_id"),
@@ -239,17 +159,10 @@ biterms <- merge(anno, anno,
 biterms <- setDT(biterms)
 biterms <- subset(biterms, dep_rel %in% c("obj", "amod"))
 biterms <- biterms[, list(cooc = .N), by = list(term1 = lemma, term2 = lemma_parent)]
-
 plt <- textplot_cooccurrence(biterms,
-                             title = "Objects of verbs and Adjectives modifying nouns", top_n = 75,
+                             title = "Objects of verbs + Adjectives-nouns",
+                             top_n = 75,
                              vertex_color = "orange", edge_color = "black",
                              fontface = "bold")
 plt
 
-
-###################################################
-### code chunk number 22: textplot-examples.Rnw:275-276
-###################################################
-print(plt)
-
-
